summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rwxr-xr-xmake-boot-image.sh6
1 files changed, 5 insertions, 1 deletions
diff --git a/make-boot-image.sh b/make-boot-image.sh
index 2f20fc0..aab28f5 100755
--- a/make-boot-image.sh
+++ b/make-boot-image.sh
@@ -140,7 +140,11 @@ while more_work and i < 10:
more_work = sset(sym, '../initrd/') or more_work
if name in ['EFI_STUB', 'EFI_VARS', 'DELL_RBU', 'USB_XHCI_HCD', 'IKCONFIG']:
- # Make kernel directly loadable by EFI, add USB3, Dell flash...
+ # Make kernel directly loadable by EFI, add USB3, Dell flash
+ more_work = sset(sym) or more_work
+
+ if name in ['DM_RAID', 'SCSI_LOWLEVEL', 'MEGARAID_SAS', 'MEGARAID_NEWGEN']:
+ # Support soft RAID (linux) and hard RAID (some cards)
more_work = sset(sym) or more_work
if debug and name in ['VIRTIO_PCI', 'VIRTIO_MMIO', 'VIRTIO_NET', 'VIRTIO_BLK', 'SCSI_LOWLEVEL', 'SCSI_VIRTIO']: